mailr12954 - in /1.3/gui/analyses: auto_noe.py auto_rx_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 10, 2011 - 11:26:
Author: bugman
Date: Fri Jun 10 11:26:14 2011
New Revision: 12954

URL: http://svn.gna.org/viewcvs/relax?rev=12954&view=rev
Log:
The NOE and Rx analysis windows now use the base class build_main_box() 
method.

Their build_main_box() methods have been renamed to build_left_box() and 
modified to suit.


Modified:
    1.3/gui/analyses/auto_noe.py
    1.3/gui/analyses/auto_rx_base.py

Modified: 1.3/gui/analyses/auto_noe.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/analyses/auto_noe.py?rev=12954&r1=12953&r2=12954&view=diff
==============================================================================
--- 1.3/gui/analyses/auto_noe.py (original)
+++ 1.3/gui/analyses/auto_noe.py Fri Jun 10 11:26:14 2011
@@ -82,9 +82,11 @@
         # The parent GUI element for this class.
         self.parent = wx.Panel(notebook, -1)
 
+        # Build the central sizer, with borders.
+        box = self.setup_analysis_element(self.parent)
+
         # Build and pack the main sizer box, then add it to the automatic 
model-free analysis frame.
-        main_box = self.build_main_box()
-        self.parent.SetSizer(main_box)
+        self.build_main_box(box)
 
 
     def add_execute_relax(self, box):
@@ -193,23 +195,19 @@
         return data, complete, missing
 
 
-    def build_main_box(self):
-        """Construct the highest level box to pack into the automatic NOE 
analysis frame.
-
-        @return:    The main box element containing all Rx GUI elements to 
pack directly into the automatic Rx analysis frame.
+    def build_left_box(self):
+        """Construct the left hand box to pack into the automatic NOE 
analysis frame.
+
+        @return:    The left hand box element containing the bitmap.
         @rtype:     wx.BoxSizer instance
         """
 
-        # Use a horizontal packing of elements.
-        box = wx.BoxSizer(wx.HORIZONTAL)
+        # Use a vertical packing of elements.
+        box = wx.BoxSizer(wx.VERTICAL)
 
         # Add the model-free bitmap picture.
         bitmap = wx.StaticBitmap(self.parent, -1, wx.Bitmap(self.bitmap, 
wx.BITMAP_TYPE_ANY))
         box.Add(bitmap, 0, wx.ADJUST_MINSIZE, 10)
-
-        # Build the right hand box and pack it next to the bitmap.
-        right_box = self.build_right_box()
-        box.Add(right_box, 1, 0, 0)
 
         # Return the box.
         return box

Modified: 1.3/gui/analyses/auto_rx_base.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/analyses/auto_rx_base.py?rev=12954&r1=12953&r2=12954&view=diff
==============================================================================
--- 1.3/gui/analyses/auto_rx_base.py (original)
+++ 1.3/gui/analyses/auto_rx_base.py Fri Jun 10 11:26:14 2011
@@ -80,9 +80,11 @@
         # The parent GUI element for this class.
         self.parent = wx.Panel(notebook, -1)
 
+        # Build the central sizer, with borders.
+        box = self.setup_analysis_element(self.parent)
+
         # Build and pack the main sizer box, then add it to the automatic 
model-free analysis frame.
-        main_box = self.build_main_box()
-        self.parent.SetSizer(main_box)
+        self.build_main_box(box)
 
 
     def add_execute_relax(self, box):
@@ -195,23 +197,19 @@
         return data, complete, missing
 
 
-    def build_main_box(self):
-        """Construct the highest level box to pack into the automatic Rx 
analysis frame.
-
-        @return:    The main box element containing all Rx GUI elements to 
pack directly into the automatic Rx analysis frame.
+    def build_left_box(self):
+        """Construct the left hand box to pack into the automatic Rx 
analysis frame.
+
+        @return:    The left hand box element containing the bitmap.
         @rtype:     wx.BoxSizer instance
         """
 
-        # Use a horizontal packing of elements.
-        box = wx.BoxSizer(wx.HORIZONTAL)
+        # Use a vertical packing of elements.
+        box = wx.BoxSizer(wx.VERTICAL)
 
         # Add the model-free bitmap picture.
-        self.bitmap_1_copy_copy = wx.StaticBitmap(self.parent, -1, 
wx.Bitmap(self.bitmap, wx.BITMAP_TYPE_ANY))
-        box.Add(self.bitmap_1_copy_copy, 0, wx.ADJUST_MINSIZE, 10)
-
-        # Build the right hand box and pack it next to the bitmap.
-        right_box = self.build_right_box()
-        box.Add(right_box, 1, 0, 0)
+        bitmap = wx.StaticBitmap(self.parent, -1, wx.Bitmap(self.bitmap, 
wx.BITMAP_TYPE_ANY))
+        box.Add(bitmap, 0, wx.ADJUST_MINSIZE, 10)
 
         # Return the box.
         return box




Related Messages


Powered by MHonArc, Updated Fri Jun 10 11:40:02 2011